@@ -111,6 +111,7 @@ class ErrorCodes(object):
         PlanIdIsInvalid = "91904"
         PriceCannotBeBlank = "81903"
         PriceFormatIsInvalid = "81904"
+        PriceIsTooLarge = "81923"
         StatusIsCanceled = "81905"
         TokenFormatIsInvalid = "81906"
         TrialDurationFormatIsInvalid = "81907"
@@ -120,6 +121,7 @@ class ErrorCodes(object):
         class Modification(object):
             AmountCannotBeBlank = "92003"
             AmountIsInvalid = "92002"
+            AmountIsTooLarge = "92023"
             CannotEditModificationsOnPastDueSubscription = "92022"
             CannotUpdateAndRemove = "92015"
             ExistingIdIsIncorrectKind = "92020"
